==> breeze_website_builder_6.5.0.tar.gz: manage/browse_template.php <==
<?php
/////////////////////////////////////////////
// Upload Template /////
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 11/13/2009	ELL
// Revised: 6/28/2013	ELL
// Implemented popup message class.
// 
//
	include ("check_session.php");
?>
<!DOCTYPE html>
<html>
<head>
<title>Browse Template | Breeze Website Builder</title>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">
<link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">

<style type="text/css">
	#install_template_btn	{	width:80px;	}
</style>

<script type="text/javascript" src="js/mouse_position.js"></script>
<script type="text/javascript" src="js/popup_msg.js"></script>
<script type="text/javascript" src="js/browse_template.js"></script>

<script>
<?php
	echo "	var UPLOAD_TEMPLATE_DELETE_ALL_PAGES_CONFIRM_MSG = \"" . UPLOAD_TEMPLATE_DELETE_ALL_PAGES_CONFIRM_MSG . "\";\n";
	echo "	var UPLOAD_TEMPLATE_UPLOADING_TEMPLATE_PLEASE_WAIT_MSG = \"" . UPLOAD_TEMPLATE_UPLOADING_TEMPLATE_PLEASE_WAIT_MSG . "\";\n";
	echo "	var YES_WORD = \"" . YES_WORD . "\";\n";
	echo "	var NO_WORD = \"" . NO_WORD . "\";\n";
?>
</script>
</head>

<body>
<table width="80%" align="center" border="0"><tr><td>
<div class="button_heading_sub_level_1"><div class="button_heading_text_sub_level_1"><?php echo UPLOAD_TEMPLATE_HEADING; ?></div><div class="button_heading_help" onClick="OpenHelpWindow();">&nbsp;</div></div>
</td></tr></table>

<form name="frmUploadTemplate" id="frmUploadTemplate" enctype="multipart/form-data" method="post" action="upload_template.php">
<table border="0" width="80%" align="center">
  <tr><td align="center"><h3><?php echo UPLOAD_TEMPLATE_SELECT_TEMPLATE_FROM_YOUR_COMPUTER; ?>:</h3></td></tr>
  <tr>
  	<td align="center"><?php echo UPLOAD_TEMPLATE_DELETE_ALL_PAGES; ?>:&nbsp;
    <input name="delete_all_pages" id="delete_all_pages" type="checkbox" value="1" onClick="DeleteConfirm();"></td>
  </tr>
  <tr>
	<td align="center"><input name="template_file" type="file"></td>
  </tr>
  <tr>
    <td align="center"><div class='button_console' id="install_template_btn" onClick="ShowUploadingMsg();"><span class='button_console_text'><?php echo INSTALL_WORD; ?></span></div></td>
  </tr>
  <tr><td align="center"><img src="theme/<?php echo $theme; ?>/images/uploading.gif" alt="<?php echo UPLOAD_TEMPLATE_UPLOADING; ?>" id="uploading_gif" style="display:none; margin-top:50px;" /></td></tr>
</table>
</form>

<?php include("lib/popup_msg.html"); ?>

<script language="javascript" type="text/javascript">
	popup_msg.HidePopupMsg();
</script>

</body>
</html>

==> breeze_website_builder_6.6.18.tar.gz: manage/browse_template.php <==
<?php
/////////////////////////////////////////////
// Upload Template /////
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 11/13/2009	ELL
// Revised: 6/28/2013	ELL
// Implemented popup message class.
// 
//
	include ("check_session.php");
?>
<!DOCTYPE html>
<html>
<head>
<title>Browse Template | Breeze Website Builder</title>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">
<link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">

<style type="text/css">
	#install_template_btn	{	width:80px;	}
	
	.button_heading_sub_level_1	{	margin-left: 10%;	}
</style>

<script type="text/javascript" src="js/mouse_position.js"></script>
<script type="text/javascript" src="js/popup_msg.js"></script>
<script type="text/javascript" src="js/browse_template.js"></script>

<script>
<?php
	echo "	var UPLOAD_TEMPLATE_DELETE_ALL_PAGES_CONFIRM_MSG = \"" . UPLOAD_TEMPLATE_DELETE_ALL_PAGES_CONFIRM_MSG . "\";\n";
	echo "	var UPLOAD_TEMPLATE_UPLOADING_TEMPLATE_PLEASE_WAIT_MSG = \"" . UPLOAD_TEMPLATE_UPLOADING_TEMPLATE_PLEASE_WAIT_MSG . "\";\n";
	echo "	var YES_WORD = \"" . YES_WORD . "\";\n";
	echo "	var NO_WORD = \"" . NO_WORD . "\";\n";
	
	echo "	var http = '$http';\n";
?>
</script>
</head>

<body>

<div class="button_heading_sub_level_1"><div class="button_heading_text_sub_level_1"><?php echo UPLOAD_TEMPLATE_HEADING; ?></div><div class="button_heading_help" onClick="OpenHelpWindow();">&nbsp;</div></div>


<form name="frmUploadTemplate" id="frmUploadTemplate" enctype="multipart/form-data" method="post" action="upload_template.php">
<table border="0" width="80%" align="center">
  <tr><td align="center"><h3><?php echo UPLOAD_TEMPLATE_SELECT_TEMPLATE_FROM_YOUR_COMPUTER; ?>:</h3></td></tr>
  <tr>
  	<td align="center"><?php echo UPLOAD_TEMPLATE_DELETE_ALL_PAGES; ?>:&nbsp;
    <input name="delete_all_pages" id="delete_all_pages" type="checkbox" value="1" onClick="DeleteConfirm();" /></td>
  </tr>
  <tr>
	<td align="center"><input name="template_file" id="template_file" type="file" /></td>
  </tr>
  <tr>
    <td align="center"><div class='button_console' id="install_template_btn" onClick="ShowUploadingMsg();"><span class='button_console_text'><?php echo INSTALL_WORD; ?></span></div></td>
  </tr>
  <tr><td align="center"><img src="theme/<?php echo $theme; ?>/images/uploading.gif" alt="<?php echo UPLOAD_TEMPLATE_UPLOADING; ?>" id="uploading_gif" style="display:none; margin-top:50px;" /></td></tr>
</table>
</form>

<?php include("lib/popup_msg.html"); ?>

<script language="javascript" type="text/javascript">
	popup_msg.HidePopupMsg();
</script>

</body>
</html>
